# -*- coding: utf-8 -*-
import os

ROOT = os.path.dirname(os.path.abspath(__file__))

FILTER_METHODS = ('GET', 'POST', 'PUT', 'DELETE')
FILTER_STATUS = ('200', )

LIMIT_URL_GROUPS = 200
LIMIT_PER_URL_GROUP = 20

STATIC_PATH_BOOTSTRAP = 'http://maxcdn.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css'
STATIC_PATH_JQUERY = 'http://code.jquery.com/jquery-1.7.2.min.js'





# -*- coding: utf-8 -*-
from setuptools import setup


setup(name='uwsgi-sloth',
    version='1.0.0',
    description='A simple uwsgi access log analyzer',
    long_description=open('README.rst').read(),
    author='piglei',
    author_email='piglei2007@gmail.com',
    url='https://github.com/piglei/uwsgi-sloth',
    keywords='uwsgi log analyzer',
    license='LICENSE',
    packages=['uwsgi_sloth'],
    data_files=[
      ('uwsgi_sloth', ['uwsgi_sloth/report.html', ])
    ],
    install_requires=[
        'jinja2',
    ],
    scripts=['uwsgi_sloth/uwsgi-sloth'])


